import { HttpClient, HttpClientModule } from '@angular/common/http';
import { Inject, Injectable, Pipe, NgModule, APP_INITIALIZER, defineInjectable, inject } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxSettingsUtils {
    /**
     * @param {?} key
     * @param {?} object
     * @return {?}
     */
    static getValueFromObject(key, object) {
        // If key is undefined, return entire object
        if (!key) {
            return object;
        }
        // Check if key is for root element
        if (key.indexOf("\\.") !== -1) {
            return object["key"];
        }
        /** @type {?} */
        let keyArr = key.split(".");
        /** @type {?} */
        let value = object[keyArr[0]];
        for (let i = 1; i < keyArr.length; i++) {
            if (value[keyArr[i]]) {
                value = value[keyArr[i]];
            }
            else {
                value = null;
                break;
            }
        }
        return value;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxSettingsService {
    /**
     * @param {?} http
     * @param {?} appConfig
     */
    constructor(http, appConfig) {
        this.http = http;
        this.appConfig = appConfig;
    }
    /**
     * @return {?}
     */
    getSettings() {
        /** @type {?} */
        const promise = this.http
            .get(this.appConfig["settingsUrl"])
            .toPromise()
            .then((/**
         * @param {?} settings
         * @return {?}
         */
        settings => {
            this.settings = settings;
        }))
            .catch((/**
         * @param {?} error
         * @return {?}
         */
        error => {
            console.error("Unable to fetch settings file: " + this.appConfig["settingsUrl"]);
            throw error;
        }));
        return promise;
    }
    /**
     * @param {?=} key
     * @param {?=} defaultValue
     * @return {?}
     */
    get(key, defaultValue) {
        /** @type {?} */
        let value = NgxSettingsUtils.getValueFromObject(key, this.settings);
        if (!value) {
            if (defaultValue) {
                return defaultValue;
            }
            throw new Error("No key found with name: " + key);
        }
        return value;
    }
}
NgxSettingsService.decorators = [
    { type: Injectable, args: [{
                providedIn: "root"
            },] }
];
/** @nocollapse */
NgxSettingsService.ctorParameters = () => [
    { type: HttpClient },
    { type: undefined, decorators: [{ type: Inject, args: ["appConfig",] }] }
];
/** @nocollapse */ NgxSettingsService.ngInjectableDef = defineInjectable({ factory: function NgxSettingsService_Factory() { return new NgxSettingsService(inject(HttpClient), inject("appConfig")); }, token: NgxSettingsService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxSettingsPipe {
    /**
     * @param {?} settingsService
     */
    constructor(settingsService) {
        this.settingsService = settingsService;
    }
    /**
     * @param {?} value
     * @param {?} args
     * @return {?}
     */
    transform(value, args) {
        return this.settingsService.get(value, args);
    }
}
NgxSettingsPipe.decorators = [
    { type: Pipe, args: [{
                name: "settingsKey"
            },] }
];
/** @nocollapse */
NgxSettingsPipe.ctorParameters = () => [
    { type: NgxSettingsService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} settingsService
 * @return {?}
 */
function getSettings(settingsService) {
    /** @type {?} */
    let factory = (/**
     * @return {?}
     */
    () => settingsService.getSettings());
    return factory;
}
class NgxSettingsModule {
    /**
     * @param {?} appConfig
     * @return {?}
     */
    static forRoot(appConfig) {
        return {
            ngModule: NgxSettingsModule,
            providers: [{ provide: "appConfig", useValue: appConfig }]
        };
    }
}
NgxSettingsModule.decorators = [
    { type: NgModule, args: [{
                imports: [HttpClientModule],
                declarations: [NgxSettingsPipe],
                providers: [
                    NgxSettingsService,
                    {
                        provide: APP_INITIALIZER,
                        useFactory: getSettings,
                        deps: [NgxSettingsService],
                        multi: true
                    }
                ],
                exports: [NgxSettingsPipe]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { getSettings, NgxSettingsModule, NgxSettingsService, NgxSettingsPipe };

//# sourceMappingURL=ngx-settings.js.map